package com.sun.xml.internal.ws.util;

import java.util.regex.Pattern;
import javax.xml.namespace.QName;
import java.net.URI;
import java.io.IOException;
import java.net.URISyntaxException;
import java.net.MalformedURLException;
import java.io.File;
import java.net.URL;
import java.util.UUID;

public final class JAXWSUtils
{
    public JAXWSUtils() {
    }
    
    public static String getUUID() {
        return UUID.randomUUID().toString();
    }
    
    public static String getFileOrURLName(String fileOrURL) {
        try {
            try {
                return escapeSpace(new URL(fileOrURL).toExternalForm());
            }
            catch (MalformedURLException e) {
                return new File(fileOrURL).getCanonicalFile().toURL().toExternalForm();
            }
        }
        catch (Exception e2) {
            return fileOrURL;
        }
    }
    
    public static URL getFileOrURL(String fileOrURL) throws IOException {
        try {
            URL url = new URL(fileOrURL);
            String scheme = url.getProtocol().toLowerCase();
            if (scheme.equals("http") || scheme.equals("https")) {
                return new URL(url.toURI().toASCIIString());
            }
            return url;
        }
        catch (URISyntaxException e) {
            return new File(fileOrURL).toURL();
        }
        catch (MalformedURLException e2) {
            return new File(fileOrURL).toURL();
        }
    }
    
    public static URL getEncodedURL(String urlStr) throws MalformedURLException {
        URL url = new URL(urlStr);
        String scheme = url.getProtocol().toLowerCase();
        if (!scheme.equals("http") && !scheme.equals("https")) {
            return url;
        }
        try {
            return new URL(url.toURI().toASCIIString());
        }
        catch (URISyntaxException e) {
            MalformedURLException malformedURLException = new MalformedURLException(e.getMessage());
            malformedURLException.initCause(e);
            throw malformedURLException;
        }
    }
    
    private static String escapeSpace(String url) {
        StringBuilder buf = new StringBuilder();
        for (int i = 0; i < url.length(); ++i) {
            if (url.charAt(i) == ' ') {
                buf.append("%20");
            }
            else {
                buf.append(url.charAt(i));
            }
        }
        return buf.toString();
    }
    
    public static String absolutize(String name) {
        try {
            URL baseURL = new File(".").getCanonicalFile().toURL();
            return new URL(baseURL, name).toExternalForm();
        }
        catch (IOException ex) {
            return name;
        }
    }
    
    public static void checkAbsoluteness(String systemId) {
        try {
            new URL(systemId);
        }
        catch (MalformedURLException mue) {
            try {
                new URI(systemId);
            }
            catch (URISyntaxException e) {
                throw new IllegalArgumentException("system ID '" + systemId + "' isn't absolute", e);
            }
        }
    }
    
    public static boolean matchQNames(QName target, QName pattern) {
        if (target == null || pattern == null) {
            return false;
        }
        if (pattern.getNamespaceURI().equals(target.getNamespaceURI())) {
            String regex = pattern.getLocalPart().replaceAll("\\*", ".*");
            return Pattern.matches(regex, target.getLocalPart());
        }
        return false;
    }
}
